@@ -146,12 +146,12 @@ void KFActionQueue::queue(KFAction *p)
 	else
 	{
 		qCDebug(KFLOPPY_LOG) << "Running action " << next->objectName() ;
-		QObject::connect(next,SIGNAL(done(KFAction*,bool)),
-			this,SLOT(actionDone(KFAction*,bool)));
+		QObject::connect(next,&KFAction::done,
+			this,&KFActionQueue::actionDone);
 		// Propagate signals
-		QObject::connect(next,SIGNAL(status(QString,int)),
-			this,SIGNAL(status(QString,int)));
-		QTimer::singleShot(0,next,SLOT(exec()));
+		QObject::connect(next,&KFAction::status,
+			this,&KFAction::status);
+		QTimer::singleShot(0,next,&KFAction::exec);
 	}
 }
 
@@ -340,7 +340,7 @@ void FloppyAction::processDone(int exitCode, QProcess::ExitStatus exitStatus)
 	{
 	        if (exitCode == 0)
 	        {
-			emit status(QString::null,100);	//krazy:exclude=nullstrassign for old broken gcc
+			emit status(QString(),100);
 			emit done(this,true);
 		}
 		else
@@ -372,10 +372,10 @@ bool FloppyAction::startProcess()
 
 	connect(theProcess, SIGNAL(finished(int,QProcess::ExitStatus)),
 		this, SLOT(processDone(int,QProcess::ExitStatus)));
-	connect(theProcess, SIGNAL(readyReadStandardOutput()),
-		this, SLOT(readStdOut()));
-	connect(theProcess, SIGNAL(readyReadStandardError()),
-		this, SLOT(readStdErr()));
+	connect(theProcess, &QProcess::readyReadStandardOutput,
+		this, &FloppyAction::readStdOut);
+	connect(theProcess, &QProcess::readyReadStandardError,
+		this, &FloppyAction::readStdErr);
 
 	theProcess->setEnv( QStringLiteral( "LC_ALL" ), QStringLiteral( "C" ) ); // We need the untranslated output of the tool
 	theProcess->setOutputChannelMode(KProcess::SeparateChannels);
@@ -473,7 +473,7 @@ void FDFormat::processStdOut(const QString &s)
     	if (s[0]==QLatin1Char('F'))
 	{
 		formatTrackCount++;
-		emit status(QString::null,	//krazy:exclude=nullstrassign for old broken gcc
+		emit status(QString(),
 			formatTrackCount * 100 / deviceInfo->tracks);
 	}
 	else if (s[0]==QLatin1Char('E'))
@@ -540,7 +540,7 @@ void FDFormat::processStdOut(const QString &s)
             const int p = regexp.cap(1).toInt();
             if ((p>=0) && (p<deviceInfo->tracks))
             {
-                    emit status(QString::null,	//krazy:exclude=nullstrassign for old broken gcc
+                    emit status(QString(),
                             p * 100 / deviceInfo->tracks);
             }
         }
@@ -555,7 +555,7 @@ DDZeroOut::DDZeroOut(QObject *p) :
     FloppyAction(p)
 {
     qCDebug(KFLOPPY_LOG) << k_funcinfo ;
-    theProcessName = QString::fromLatin1("dd");
+    theProcessName = QStringLiteral("dd");
     setObjectName( QStringLiteral("DD" ));
 }
 
@@ -612,7 +612,7 @@ void DDZeroOut::processDone(int exitCode, QProcess::ExitStatus exitStatus)
      *
      * ### TODO: really check if the exit is not on an other error and then abort the formatting
      */
-    emit status(QString::null,100);	//krazy:exclude=nullstrassign for old broken gcc
+    emit status(QString(),100);
     emit done(this,true);
 }
 
